Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7)

Unified Diff: include/core/SkColorSpace.h

Issue 2408133009: Add NewRGB() with float gamma to SkColorSpace public API
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/codec/SkPngCodec.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/core/SkColorSpace.h
diff --git a/include/core/SkColorSpace.h b/include/core/SkColorSpace.h
index 26dd2211f5d09d982dd0cee47c1f562dda1f5f19..fc68fd4587ad085b50a2c6b8053655b908272afb 100644
--- a/include/core/SkColorSpace.h
+++ b/include/core/SkColorSpace.h
@@ -89,12 +89,14 @@ public:
/**
* Create an SkColorSpace from a transfer function and a color gamut.
*
* Transfer function can be specified as a render target or as the coefficients to an equation.
* Gamut is specified using the matrix transformation to XYZ D50.
*/
static sk_sp<SkColorSpace> NewRGB(RenderTargetGamma gamma, const SkMatrix44& toXYZD50);
static sk_sp<SkColorSpace> NewRGB(const SkColorSpaceTransferFn& coeffs,
const SkMatrix44& toXYZD50);
+ static sk_sp<SkColorSpace> NewRGB(const float exponents[3], const SkMatrix44& toXYZD50);
/**
* Create a common, named SkColorSpace.
« no previous file with comments | « no previous file | src/codec/SkPngCodec.cpp » ('j') | no next file with comments »
@@ -89,12 +89,14 @@ public:
* Create an SkColorSpace from a transfer function and a color gamut.
*
- * Transfer function can be specified as a render target or as the coefficients to an equation.
+ * Transfer function can be specified as a render target, as the coefficients to an equation,
+ * or as three exponents (R, G, B).
* Gamut is specified using the matrix transformation to XYZ D50.
*/

Powered by Google App Engine
This is Rietveld 408576698